import 'package:flutter/foundation.dart';

import 'package:wordguessing/models/word.dart';

class Data extends ChangeNotifier {
  // Language
  String _lang = '';

  // randomization
  Word? _word;
  List<Word> _otherWords = [];
  List<Word> _images = [];
  final int _recentWordsCount = 20;
  List<String> _recentWordsKeys = [];

  // game data
  int _questionsCount = 0;
  int _goodAnswers = 0;
  int _wrongAnswers = 0;

  String get lang => _lang;

  void updateLang(String value) {
    _lang = value;
    notifyListeners();
  }

  Word? get word => _word;

  void updateWord(Word? newWord) {
    _word = newWord;
    if ((newWord != null) && (newWord.key != '')) {
      _recentWordsKeys.insert(0, newWord.key);
      _recentWordsKeys = _recentWordsKeys.take(_recentWordsCount).toList();
    }
    notifyListeners();
  }

  bool isRecentlyPicked(String word) {
    return _recentWordsKeys.contains(word);
  }

  List<Word> get otherWords => _otherWords;

  void updateOtherWords(List<Word> words) {
    _otherWords = words;
    notifyListeners();
  }

  List<Word> get images => _images;

  void updateImages(List<Word> images) {
    _images = images;
    notifyListeners();
  }

  void resetGame() {
    updateLang('');
    updateQuestionsCount(0);
    updateGoodAnswers(0);
    updateWrongAnswers(0);
    updateWord(null);
    updateOtherWords([]);
    updateImages([]);
    notifyListeners();
  }

  int get questionsCount => _questionsCount;

  void updateQuestionsCount(int value) {
    _questionsCount = value;
    notifyListeners();
  }

  int get goodAnswers => _goodAnswers;

  void updateGoodAnswers(int value) {
    _goodAnswers = value;
    notifyListeners();
  }

  int get wrongAnswers => _wrongAnswers;

  void updateWrongAnswers(int value) {
    _wrongAnswers = value;
    notifyListeners();
  }
}
